@@ -7,7 +7,7 @@ use File::Copy;
 use Archive::SevenZip 'AZ_OK';
 
 use vars qw($VERSION);
-$VERSION= '0.05';
+$VERSION= '0.06';
 
 sub new {
     my( $class, %options )= @_;
@@ -44,7 +44,8 @@ sub writeToFileNamed {
 
 sub addFileOrDirectory {
     my($self, $name, $newName, $compressionLevel) = @_;
-    $newName //= $name;
+    $newName = $name
+        unless defined $newName;
     $self->sevenZip->add(
         items => [ [$name, $newName] ],
         compression => $compressionLevel
